==> 0.0.1.tar.gz: lib/model/executepayment/MFExecutePaymentRequest.dart <==
class MFExecutePaymentRequest {
  String paymentMethodId;
  String customerName;
  String displayCurrencyIso;
  String mobileCountryCode;
  String customerMobile;
  String customerEmail;
  String invoiceValue;
  String callBackUrl;
  String errorUrl;
  String language;
  String customerReference;
  String customerCivilId;
  String userDefinedField;
  CustomerAddress customerAddress;
  String expiryDate;
  String supplierCode;
  List<InvoiceItems> invoiceItems;

  MFExecutePaymentRequest(paymentMethodId, invoiceValue) {
    this.paymentMethodId = paymentMethodId;
    this.invoiceValue = invoiceValue;
  }

//  MFExecutePaymentRequest.All(
//      {this.paymentMethodId,
//        this.customerName,
//        this.displayCurrencyIso,
//        this.mobileCountryCode,
//        this.customerMobile,
//        this.customerEmail,
//        this.invoiceValue,
//        this.callBackUrl,
//        this.errorUrl,
//        this.language,
//        this.customerReference,
//        this.customerCivilId,
//        this.userDefinedField,
//        this.customerAddress,
//        this.expiryDate,
//        this.supplierCode,
//        this.invoiceItems});

  MFExecutePaymentRequest.fromJson(Map<String, dynamic> json) {
    paymentMethodId = json['PaymentMethodId'];
    customerName = json['CustomerName'];
    displayCurrencyIso = json['DisplayCurrencyIso'];
    mobileCountryCode = json['MobileCountryCode'];
    customerMobile = json['CustomerMobile'];
    customerEmail = json['CustomerEmail'];
    invoiceValue = json['InvoiceValue'];
    callBackUrl = json['CallBackUrl'];
    errorUrl = json['ErrorUrl'];
    language = json['Language'];
    customerReference = json['CustomerReference'];
    customerCivilId = json['CustomerCivilId'];
    userDefinedField = json['UserDefinedField'];
    customerAddress = json['CustomerAddress'] != null
        ? new CustomerAddress.fromJson(json['CustomerAddress'])
        : null;
    expiryDate = json['ExpiryDate'];
    supplierCode = json['SupplierCode'];
    if (json['InvoiceItems'] != null) {
      invoiceItems = new List<InvoiceItems>();
      json['InvoiceItems'].forEach((v) {
        invoiceItems.add(new InvoiceItems.fromJson(v));
      });
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    if(this.paymentMethodId != null) data['PaymentMethodId'] = this.paymentMethodId;
    if(this.customerName != null) data['CustomerName'] = this.customerName;
    if(this.displayCurrencyIso != null) data['DisplayCurrencyIso'] = this.displayCurrencyIso;
    if(this.mobileCountryCode != null) data['MobileCountryCode'] = this.mobileCountryCode;
    if(this.customerMobile != null) data['CustomerMobile'] = this.customerMobile;
    if(this.customerEmail != null) data['CustomerEmail'] = this.customerEmail;
    if(this.invoiceValue != null) data['InvoiceValue'] = this.invoiceValue;
    if(this.callBackUrl != null) data['CallBackUrl'] = this.callBackUrl;
    if(this.errorUrl != null) data['ErrorUrl'] = this.errorUrl;
    if(this.language != null) data['Language'] = this.language;
    if(this.customerReference != null) data['CustomerReference'] = this.customerReference;
    if(this.customerCivilId != null) data['CustomerCivilId'] = this.customerCivilId;
    if(this.userDefinedField != null) data['UserDefinedField'] = this.userDefinedField;
    if (this.customerAddress != null) {
      data['CustomerAddress'] = this.customerAddress.toJson();
    }
    if(this.expiryDate != null) data['ExpiryDate'] = this.expiryDate;
    if(this.supplierCode != null) data['SupplierCode'] = this.supplierCode;
    if(this.invoiceItems != null) {
      data['InvoiceItems'] = this.invoiceItems.map((v) => v.toJson()).toList();
    }

    return data;
  }
}

class CustomerAddress {
  String block;
  String street;
  String houseBuildingNo;
  String address;
  String addressInstructions;

  CustomerAddress(
      {this.block,
        this.street,
        this.houseBuildingNo,
        this.address,
        this.addressInstructions});

  CustomerAddress.fromJson(Map<String, dynamic> json) {
    block = json['Block'];
    street = json['Street'];
    houseBuildingNo = json['HouseBuildingNo'];
    address = json['Address'];
    addressInstructions = json['AddressInstructions'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    if(this.block != null) data['Block'] = this.block;
    if(this.street != null) data['Street'] = this.street;
    if(this.houseBuildingNo != null) data['HouseBuildingNo'] = this.houseBuildingNo;
    if(this.address != null) data['Address'] = this.address;
    if(this.addressInstructions != null) data['AddressInstructions'] = this.addressInstructions;
    return data;
  }
}

class InvoiceItems {
  String itemName;
  String quantity;
  String unitPrice;

  InvoiceItems({this.itemName, this.quantity, this.unitPrice});

  InvoiceItems.fromJson(Map<String, dynamic> json) {
    itemName = json['ItemName'];
    quantity = json['Quantity'];
    unitPrice = json['UnitPrice'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['ItemName'] = this.itemName;
    data['Quantity'] = this.quantity;
    data['UnitPrice'] = this.unitPrice;
    return data;
  }
}

==> 0.1.2.tar.gz: lib/model/executepayment/MFExecutePaymentRequest.dart <==
class MFExecutePaymentRequest {
  String paymentMethodId;
  String customerName;
  String displayCurrencyIso;
  String mobileCountryCode;
  String customerMobile;
  String customerEmail;
  String invoiceValue;
  String callBackUrl;
  String errorUrl;
  String language;
  String customerReference;
  String customerCivilId;
  String userDefinedField;
  CustomerAddress customerAddress;
  String expiryDate;
  String supplierCode;
  List<InvoiceItem> invoiceItems;

  MFExecutePaymentRequest(paymentMethodId, invoiceValue) {
    this.paymentMethodId = paymentMethodId;
    this.invoiceValue = invoiceValue;
  }

//  MFExecutePaymentRequest.All(
//      {this.paymentMethodId,
//        this.customerName,
//        this.displayCurrencyIso,
//        this.mobileCountryCode,
//        this.customerMobile,
//        this.customerEmail,
//        this.invoiceValue,
//        this.callBackUrl,
//        this.errorUrl,
//        this.language,
//        this.customerReference,
//        this.customerCivilId,
//        this.userDefinedField,
//        this.customerAddress,
//        this.expiryDate,
//        this.supplierCode,
//        this.invoiceItems});

  MFExecutePaymentRequest.fromJson(Map<String, dynamic> json) {
    paymentMethodId = json['PaymentMethodId'];
    customerName = json['CustomerName'];
    displayCurrencyIso = json['DisplayCurrencyIso'];
    mobileCountryCode = json['MobileCountryCode'];
    customerMobile = json['CustomerMobile'];
    customerEmail = json['CustomerEmail'];
    invoiceValue = json['InvoiceValue'];
    callBackUrl = json['CallBackUrl'];
    errorUrl = json['ErrorUrl'];
    language = json['Language'];
    customerReference = json['CustomerReference'];
    customerCivilId = json['CustomerCivilId'];
    userDefinedField = json['UserDefinedField'];
    customerAddress = json['CustomerAddress'] != null
        ? new CustomerAddress.fromJson(json['CustomerAddress'])
        : null;
    expiryDate = json['ExpiryDate'];
    supplierCode = json['SupplierCode'];
    if (json['InvoiceItems'] != null) {
      invoiceItems = new List<InvoiceItem>();
      json['InvoiceItems'].forEach((v) {
        invoiceItems.add(new InvoiceItem.fromJson(v));
      });
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    if(this.paymentMethodId != null) data['PaymentMethodId'] = this.paymentMethodId;
    if(this.customerName != null) data['CustomerName'] = this.customerName;
    if(this.displayCurrencyIso != null) data['DisplayCurrencyIso'] = this.displayCurrencyIso;
    if(this.mobileCountryCode != null) data['MobileCountryCode'] = this.mobileCountryCode;
    if(this.customerMobile != null) data['CustomerMobile'] = this.customerMobile;
    if(this.customerEmail != null) data['CustomerEmail'] = this.customerEmail;
    if(this.invoiceValue != null) data['InvoiceValue'] = this.invoiceValue;
    if(this.callBackUrl != null) data['CallBackUrl'] = this.callBackUrl;
    if(this.errorUrl != null) data['ErrorUrl'] = this.errorUrl;
    if(this.language != null) data['Language'] = this.language;
    if(this.customerReference != null) data['CustomerReference'] = this.customerReference;
    if(this.customerCivilId != null) data['CustomerCivilId'] = this.customerCivilId;
    if(this.userDefinedField != null) data['UserDefinedField'] = this.userDefinedField;
    if (this.customerAddress != null) {
      data['CustomerAddress'] = this.customerAddress.toJson();
    }
    if(this.expiryDate != null) data['ExpiryDate'] = this.expiryDate;
    if(this.supplierCode != null) data['SupplierCode'] = this.supplierCode;
    if(this.invoiceItems != null) {
      data['InvoiceItems'] = this.invoiceItems.map((v) => v.toJson()).toList();
    }

    return data;
  }
}

class CustomerAddress {
  String block;
  String street;
  String houseBuildingNo;
  String address;
  String addressInstructions;

  CustomerAddress(
      {this.block,
        this.street,
        this.houseBuildingNo,
        this.address,
        this.addressInstructions});

  CustomerAddress.fromJson(Map<String, dynamic> json) {
    block = json['Block'];
    street = json['Street'];
    houseBuildingNo = json['HouseBuildingNo'];
    address = json['Address'];
    addressInstructions = json['AddressInstructions'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    if(this.block != null) data['Block'] = this.block;
    if(this.street != null) data['Street'] = this.street;
    if(this.houseBuildingNo != null) data['HouseBuildingNo'] = this.houseBuildingNo;
    if(this.address != null) data['Address'] = this.address;
    if(this.addressInstructions != null) data['AddressInstructions'] = this.addressInstructions;
    return data;
  }
}

class InvoiceItem {
  String itemName;
  String quantity;
  String unitPrice;

  InvoiceItem({this.itemName, this.quantity, this.unitPrice});

  InvoiceItem.fromJson(Map<String, dynamic> json) {
    itemName = json['ItemName'];
    quantity = json['Quantity'];
    unitPrice = json['UnitPrice'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['ItemName'] = this.itemName;
    data['Quantity'] = this.quantity;
    data['UnitPrice'] = this.unitPrice;
    return data;
  }
}
